@@ -131,8 +131,6 @@ class CLIParser:
                 "remove",
                 "cloudwizard",
                 "follow",
-                "hold",
-                "start",
             ]
         ):
             parser.add_argument(
@@ -338,6 +336,8 @@ class CLIParser:
                 "resize",
                 "cloudwizard",
                 "boost",
+                "hold",
+                "start",
             ]
         ):
             parser.add_argument(
@@ -345,7 +345,7 @@ class CLIParser:
                 "-y",
                 action="store_true",
                 required=False,
-                help="perform destructive actions without requiring user confirmation",
+                help="perform modifying actions without requiring user confirmation",
             )
 
         if any(module in sys.argv[0] for module in ["delete", "download"]):
@@ -639,18 +639,19 @@ class CLIParser:
             )
 
         if "boost" in sys.argv[0]:
-            parser.add_argument(
-                "allowance",
-                metavar="<allowance-ID>",
-                type=str,
-                help=("the YellowDog ID of the allowance to boost"),
-            )
             parser.add_argument(
                 "boost_hours",
                 metavar="<boost hours>",
                 type=int,
                 help="the number of hours to boost the allowance by",
             )
+            parser.add_argument(
+                "allowances",
+                metavar="<allowance-ID> [<allowance-ID>]",
+                nargs="+",
+                type=str,
+                help="the YellowDog ID(s) of the allowance(s) to boost",
+            )
 
         if "shutdown" in sys.argv[0]:
             parser.add_argument(
@@ -763,6 +764,16 @@ class CLIParser:
                 required=False,
                 help="allow updates without user confirmation",
             )
+            parser.add_argument(
+                "--match-allowances-by-description",
+                "-M",
+                action="store_true",
+                required=False,
+                help=(
+                    "match using the 'description' property when updating "
+                    "(using yd-create) or removing allowances"
+                ),
+            )
         if "create" in sys.argv[0]:
             parser.add_argument(
                 "--show-keyring-passwords",
@@ -968,6 +979,17 @@ class CLIParser:
                 ),
             )
 
+        if any(module in sys.argv[0] for module in ["create"]):
+            parser.add_argument(
+                "--no-resequence",
+                action="store_true",
+                required=False,
+                help=(
+                    "don't re-sequence resources prior  to creation (e.g., "
+                    "putting source templates before requirement templates)"
+                ),
+            )
+
         self.args = parser.parse_args()
 
         if self.args.docs:
@@ -1380,14 +1402,24 @@ class CLIParser:
 
     @property
     @allow_missing_attribute
-    def allowance(self) -> str:
-        return self.args.allowance
+    def allowance_list(self) -> List[str]:
+        return self.args.allowances
 
     @property
     @allow_missing_attribute
     def boost_hours(self) -> int:
         return self.args.boost_hours
 
+    @property
+    @allow_missing_attribute
+    def no_resequence(self) -> Optional[bool]:
+        return self.args.no_resequence
+
+    @property
+    @allow_missing_attribute
+    def match_allowances_by_description(self) -> Optional[bool]:
+        return self.args.match_allowances_by_description
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
